# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['hamburg']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.0.0', 'yarl>=1.6.0']

setup_kwargs = {
    'name': 'hamburg',
    'version': '0.3.0',
    'description': 'Asynchronous Python client providing Urban Data information of Hamburg',
    'long_description': '## Python - UDP Hamburg Client\n\n<!-- PROJECT SHIELDS -->\n[![GitHub Release][releases-shield]][releases]\n[![Python Versions][python-versions-shield]][pypi]\n![Project Stage][project-stage-shield]\n![Project Maintenance][maintenance-shield]\n[![License][license-shield]](LICENSE)\n\n[![GitHub Activity][commits-shield]][commits-url]\n[![Forks][forks-shield]][forks-url]\n[![Stargazers][stars-shield]][stars-url]\n[![Issues][issues-shield]][issues-url]\n[![GitHub Last Commit][last-commit-shield]][commits-url]\n\n[![Code Quality][code-quality-shield]][code-quality]\n[![Maintainability][maintainability-shield]][maintainability-url]\n[![Code Coverage][codecov-shield]][codecov-url]\n\n[![Build Status][build-shield]][build-url]\n[![Typing Status][typing-shield]][typing-url]\n\nAsynchronous Python client for the urban datasets of Hamburg (Germany).\n\n## About\n\nA python package with which you can retrieve data from the Urban Data Platform of Hamburg via [their API][api]. This package was initially created to only retrieve parking data from the API, but the code base is made in such a way that it is easy to extend for other datasets from the same platform.\n\n## Installation\n\n```bash\npip install hamburg\n```\n\n## Datasets\n\nYou can read the following datasets with this package:\n\n- [Disabled parking spaces / Behindertenstellplätze][disabled_parking] (671)\n- [Park and rides occupancy / Park + Ride Anlagen][park_and_ride] (31)\n- [Garages occupancy / Parkhäuser][garages] (46 live data / 125 total)\n\nThere are a number of parameters you can set to retrieve the data:\n\n- **limit** (default: 10) - How many results you want to retrieve.\n- **bulk** (default: false) - If string is true, number of rows will be ignored and the entire result will be returned.\n\n<details>\n    <summary>Click here to get more details</summary>\n\n### Disabled parking spaces\n\n| Variable | Type | Description |\n| :------- | :--- | :---------- |\n| `spot_id` | string | The ID of the parking spot |\n| `street` | string | The street name |\n| `limitation` | string | Some locations have window times where the location is only specific for disabled parking, outside these times everyone is allowed to park there |\n| `number` | string | The number of parking spots on this location |\n| `longitude` | float | The longitude of the parking spot |\n| `latitude` | float | The latitude of the parking spot |\n\n### Park and Rides\n\n| Variable | Type | Description |\n| :------- | :--- | :---------- |\n| `spot_id` | string | The ID of the park and ride |\n| `name` | string | The name of the park and ride |\n| `park_type` | string | The parking type of the park and ride |\n| `address` | string | The address of the park and ride |\n| `construction_year` | string | The year the park and ride was constructed |\n| `public_transport_line` | string | The public transport line the park and ride is connected to |\n| `disabled_parking_spaces` | int | The number of disabled parking spaces on the park and ride |\n| `tickets` | dict | The type of tickets available for the park and ride |\n| `url` | string | The URL of the park and ride where you can find more information |\n| `free_space` | int | The number of free spaces on the park and ride |\n| `capacity` | int | The capacity of the park and ride |\n| `availability_pct` | float | The percentage of the park and ride that is available |\n| `longitude` | float | The longitude of the park and ride |\n| `latitude` | float | The latitude of the park and ride |\n| `updated_at` | datetime | The date and time the park and ride was last updated |\n\n### Garages\n\nExtra parameters to filter the data:\n\n- **available** (default: None) - Allows you to filter based on available spaces, using operators such as `<`, `<=`, `>` and `>=`.\n\n| Variable | Type | Description |\n| :------- | :--- | :---------- |\n| `spot_id` | string | The ID of the garage |\n| `name` | string | The name of the pgarage |\n| `park_type` | string | The parking type of the garage |\n| `disabled_parking_spaces` | int | The number of disabled parking spaces in the garage |\n| `status` | string | The status of the garage (**frei**, **nahezu belegt**, **besetzt** or **keine Auslastungsdaten**) |\n| `address` | string | The address of the garage |\n| `price` | string | The price list that is used for parking in a garage |\n| `data_origin` | string | Where data originally comes from |\n| `free_space` | int | The number of free spaces in the garage |\n| `capacity` | int | The capacity of the garage |\n| `availability_pct` | float | The percentage that is still available in the garage |\n| `longitude` | float | The longitude of the garage |\n| `latitude` | float | The latitude of the garage |\n| `updated_at` | datetime | The date and time the garage was last updated |\n\n</details>\n\n## Example\n\n```python\nimport asyncio\n\nfrom hamburg import UDPHamburg\n\n\nasync def main() -> None:\n    """Show example on using the UDP Hamburg API client."""\n    async with UDPHamburg() as client:\n        disabled_parkings = await client.disabled_parkings()\n        park_and_rides = await client.park_and_rides()\n        garages = await client.garages()\n        print(disabled_parkings)\n        print(park_and_rides)\n        print(garages)\n\n\nif __name__ == "__main__":\n    asyncio.run(main())\n```\n\n## Use cases\n\n[NIPKaart.nl][nipkaart]\n\nA website that provides insight into where disabled parking spaces are, based on data from users and municipalities. Operates mainly in the Netherlands, but also has plans to process data from abroad.\n\n## Contributing\n\nThis is an active open-source project. We are always open to people who want to\nuse the code or contribute to it.\n\nWe\'ve set up a separate document for our\n[contribution guidelines](CONTRIBUTING.md).\n\nThank you for being involved! :heart_eyes:\n\n## Setting up development environment\n\nThis Python project is fully managed using the [Poetry][poetry] dependency\nmanager.\n\nYou need at least:\n\n- Python 3.9+\n- [Poetry][poetry-install]\n\nInstall all packages, including all development requirements:\n\n```bash\npoetry install\n```\n\nPoetry creates by default an virtual environment where it installs all\nnecessary pip packages, to enter or exit the venv run the following commands:\n\n```bash\npoetry shell\nexit\n```\n\nSetup the pre-commit check, you must run this inside the virtual environment:\n\n```bash\npre-commit install\n```\n\n*Now you\'re all set to get started!*\n\nAs this repository uses the [pre-commit][pre-commit] framework, all changes\nare linted and tested with each commit. You can run all checks and tests\nmanually, using the following command:\n\n```bash\npoetry run pre-commit run --all-files\n```\n\nTo run just the Python tests:\n\n```bash\npoetry run pytest\n```\n\n## License\n\nMIT License\n\nCopyright (c) 2022 Klaas Schoute\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n\n[api]: https://api.hamburg.de/datasets/v1/\n[nipkaart]: https://www.nipkaart.nl\n\n[disabled_parking]: https://api.hamburg.de/datasets/v1/behindertenstellplaetze\n[park_and_ride]: https://api.hamburg.de/datasets/v1/p_und_r\n[garages]: https://api.hamburg.de/datasets/v1/parkhaeuser\n\n<!-- MARKDOWN LINKS & IMAGES -->\n[build-shield]: https://github.com/klaasnicolaas/python-hamburg/actions/workflows/tests.yaml/badge.svg\n[build-url]: https://github.com/klaasnicolaas/python-hamburg/actions/workflows/tests.yaml\n[code-quality-shield]: https://img.shields.io/lgtm/grade/python/g/klaasnicolaas/python-hamburg.svg?logo=lgtm&logoWidth=18\n[code-quality]: https://lgtm.com/projects/g/klaasnicolaas/python-hamburg/context:python\n[commits-shield]: https://img.shields.io/github/commit-activity/y/klaasnicolaas/python-hamburg.svg\n[commits-url]: https://github.com/klaasnicolaas/python-hamburg/commits/main\n[codecov-shield]: https://codecov.io/gh/klaasnicolaas/python-hamburg/branch/main/graph/badge.svg?token=4Y4YAYHR2D\n[codecov-url]: https://codecov.io/gh/klaasnicolaas/python-hamburg\n[forks-shield]: https://img.shields.io/github/forks/klaasnicolaas/python-hamburg.svg\n[forks-url]: https://github.com/klaasnicolaas/python-hamburg/network/members\n[issues-shield]: https://img.shields.io/github/issues/klaasnicolaas/python-hamburg.svg\n[issues-url]: https://github.com/klaasnicolaas/python-hamburg/issues\n[license-shield]: https://img.shields.io/github/license/klaasnicolaas/python-hamburg.svg\n[last-commit-shield]: https://img.shields.io/github/last-commit/klaasnicolaas/python-hamburg.svg\n[maintenance-shield]: https://img.shields.io/maintenance/yes/2022.svg\n[maintainability-shield]: https://api.codeclimate.com/v1/badges/5041849456b7348f3bc7/maintainability\n[maintainability-url]: https://codeclimate.com/github/klaasnicolaas/python-hamburg/maintainability\n[project-stage-shield]: https://img.shields.io/badge/project%20stage-experimental-yellow.svg\n[pypi]: https://pypi.org/project/hamburg/\n[python-versions-shield]: https://img.shields.io/pypi/pyversions/hamburg\n[typing-shield]: https://github.com/klaasnicolaas/python-hamburg/actions/workflows/typing.yaml/badge.svg\n[typing-url]: https://github.com/klaasnicolaas/python-hamburg/actions/workflows/typing.yaml\n[releases-shield]: https://img.shields.io/github/release/klaasnicolaas/python-hamburg.svg\n[releases]: https://github.com/klaasnicolaas/python-hamburg/releases\n[stars-shield]: https://img.shields.io/github/stars/klaasnicolaas/python-hamburg.svg\n[stars-url]: https://github.com/klaasnicolaas/python-hamburg/stargazers\n\n[poetry-install]: https://python-poetry.org/docs/#installation\n[poetry]: https://python-poetry.org\n[pre-commit]: https://pre-commit.com\n',
    'author': 'Klaas Schoute',
    'author_email': 'hello@student-techlife.com',
    'maintainer': 'Klaas Schoute',
    'maintainer_email': 'hello@student-techlife.com',
    'url': 'https://github.com/klaasnicolaas/python-hamburg',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
